summaryrefslogtreecommitdiff
path: root/plugins/LinkbackPlugin.php
diff options
context:
space:
mode:
authorEvan Prodromou <evan@controlyourself.ca>2009-08-25 18:29:56 -0400
committerEvan Prodromou <evan@controlyourself.ca>2009-08-25 18:29:56 -0400
commitbfc66cfe1923c8610f693d4309b7b09764ca4dcb (patch)
treee3e2a02ce9f4fd343cf749d17485c6b8a2296ce1 /plugins/LinkbackPlugin.php
parent25062074540d59c723f31665676abd816cb8895a (diff)
Laconica in plugins
Diffstat (limited to 'plugins/LinkbackPlugin.php')
-rw-r--r--plugins/LinkbackPlugin.php18
1 files changed, 9 insertions, 9 deletions
diff --git a/plugins/LinkbackPlugin.php b/plugins/LinkbackPlugin.php
index 93a0294c4..7bf7fa619 100644
--- a/plugins/LinkbackPlugin.php
+++ b/plugins/LinkbackPlugin.php
@@ -1,6 +1,6 @@
<?php
/**
* Laconica, the distributed open-source microblogging tool
*
* Plugin to do linkbacks for notices containing links
*
@@ -20,11 +20,11 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @category Plugin
- * @package Laconica
- * @author Evan Prodromou <evan@controlyourself.ca>
- * @copyright 2009 Control Yourself, Inc.
+ * @package StatusNet
+ * @author Evan Prodromou <evan@status.net>
+ * @copyright 2009 StatusNet, Inc.
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*/
if (!defined('LACONICA')) {
@@ -42,10 +42,10 @@ define('LINKBACKPLUGIN_VERSION', '0.1');
* are URLs, we test each URL to see if it supports any
*
* @category Plugin
- * @package Laconica
- * @author Evan Prodromou <evan@controlyourself.ca>
+ * @package StatusNet
+ * @author Evan Prodromou <evan@status.net>
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*
* @see Event
*/
@@ -225,6 +225,6 @@ class LinkbackPlugin extends Plugin
function userAgent()
{
return 'LinkbackPlugin/'.LINKBACKPLUGIN_VERSION .
- ' Laconica/' . LACONICA_VERSION;
+ ' StatusNet/' . LACONICA_VERSION;
}
}
@@ -1,6 +1,6 @@
<?php
/**
- * Laconica, the distributed open-source microblogging tool
+ * StatusNet, the distributed open-source microblogging tool
*
* Plugin to do linkbacks for notices containing links